@@ -1,7 +1,7 @@
 #
 # This file is part of XML-Ant-BuildFile
 #
-# This software is copyright (c) 2011 by GSI Commerce.
+# This software is copyright (c) 2014 by GSI Commerce.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,16 +10,15 @@ use utf8;
 use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 
 package XML::Ant::BuildFile::Role::HasProjects;
-
-BEGIN {
-    $XML::Ant::BuildFile::Role::HasProjects::VERSION = '0.215';
-}
+$XML::Ant::BuildFile::Role::HasProjects::VERSION = '0.216';
 
 # ABSTRACT: Compose a collection of Ant build file projects
 
 use strict;
 use Carp;
 use English '-no_match_vars';
+## no critic (Subroutines::ProhibitCallsToUndeclaredSubs)
+use List::Util 1.33 'any';
 use Moose::Role;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose 'HashRef';
@@ -28,7 +27,7 @@ use Path::Class;
 use Regexp::DefaultFlags;
 ## no critic (RequireDotMatchAnything, RequireExtendedFormatting)
 ## no critic (RequireLineBoundaryMatching)
-use TryCatch;
+use Try::Tiny;
 use XML::Ant::BuildFile::Project;
 use namespace::autoclean;
 
@@ -68,30 +67,32 @@ sub _make_ant_finder_callback {
         for ( 0 .. $#dir_list ) {    # skip symlinks
             return if -l file( @dir_list[ 0 .. $ARG ] )->stringify();
         }
-        return if 'CVS' ~~ @dir_list or '.svn' ~~ @dir_list;   # skip SCM dirs
+        return                       # skip SCM dirs
+            if any { 'CVS' eq $_ } @dir_list
+            or any { '.svn' eq $_ } @dir_list;
 
         # look for matching XML files but only carp if parse error
-        my $error;
-        try {
-            ## no critic (ValuesAndExpressions::ProhibitAccessOfPrivateData)
-            $projects_ref->{"$path"}
-                = XML::Ant::BuildFile::Project->new( file => $path );
+        ## no critic (ValuesAndExpressions::ProhibitAccessOfPrivateData)
+        $projects_ref->{"$path"} = try {
+            XML::Ant::BuildFile::Project->new( file => $path );
         }
-        catch($error) { carp $error };
+        catch { carp $_ };
         return;
     };
 }
 
+no Moose::Role;
+
 1;
 
 __END__
 
 =pod
 
-=for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
-cpants kwalitee diff irc mailto metadata placeholders
+=encoding UTF-8
 
-=encoding utf8
+=for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
+cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 NAME
 
@@ -99,7 +100,7 @@ XML::Ant::BuildFile::Role::HasProjects - Compose a collection of Ant build file
 
 =head1 VERSION
 
-version 0.215
+version 0.216
 
 =head1 SYNOPSIS
 
@@ -152,6 +153,14 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/XML-Ant-BuildFile>
+
+=item *
+
 Search CPAN
 
 The default CPAN search engine, useful to view POD in HTML format.
@@ -164,13 +173,13 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Ant-BuildFile>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Ant-BuildFile>
 
 =item *
 
 AnnoCPAN
 
-The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/XML-Ant-BuildFile>
 
@@ -196,7 +205,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/XML-Ant-BuildFile>
+L<http://cpants.cpanauthors.org/dist/XML-Ant-BuildFile>
 
 =item *
 
@@ -210,7 +219,7 @@ L<http://www.cpantesters.org/distro/X/XML-Ant-BuildFile>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=XML-Ant-BuildFile>
 
@@ -246,7 +255,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by GSI Commerce.
+This software is copyright (c) 2014 by GSI Commerce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
