@@ -1,7 +1,7 @@
 #
 # This file is part of XML-Ant-BuildFile
 #
-# This software is copyright (c) 2011 by GSI Commerce.
+# This software is copyright (c) 2014 by GSI Commerce.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,10 +10,7 @@ use utf8;
 use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 
 package XML::Ant::BuildFile::Task;
-
-BEGIN {
-    $XML::Ant::BuildFile::Task::VERSION = '0.215';
-}
+$XML::Ant::BuildFile::Task::VERSION = '0.216';
 
 # ABSTRACT: Role for Ant build file tasks
 
@@ -31,14 +28,18 @@ has task_name => ( ro, lazy,
     default  => sub { $ARG[0]->node->nodeName },
 );
 
+no Moose::Role;
+
 1;
 
+__END__
+
 =pod
 
-=for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
-cpants kwalitee diff irc mailto metadata placeholders
+=encoding UTF-8
 
-=encoding utf8
+=for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
+cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 NAME
 
@@ -46,7 +47,7 @@ XML::Ant::BuildFile::Task - Role for Ant build file tasks
 
 =head1 VERSION
 
-version 0.215
+version 0.216
 
 =head1 SYNOPSIS
 
@@ -89,6 +90,14 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/XML-Ant-BuildFile>
+
+=item *
+
 Search CPAN
 
 The default CPAN search engine, useful to view POD in HTML format.
@@ -101,13 +110,13 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Ant-BuildFile>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Ant-BuildFile>
 
 =item *
 
 AnnoCPAN
 
-The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/XML-Ant-BuildFile>
 
@@ -133,7 +142,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/XML-Ant-BuildFile>
+L<http://cpants.cpanauthors.org/dist/XML-Ant-BuildFile>
 
 =item *
 
@@ -147,7 +156,7 @@ L<http://www.cpantesters.org/distro/X/XML-Ant-BuildFile>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=XML-Ant-BuildFile>
 
@@ -183,11 +192,9 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by GSI Commerce.
+This software is copyright (c) 2014 by GSI Commerce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__END__
